FlutterApplovinMax class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

appLovinAdListener → Map<String, AppLovinAdListener>
final

Static Methods

handleMethod(MethodCall call, AppLovinListener listener) → Future<void>
initInterstitialAd(String unitId) → Future<void>
initRewardAd(String unitId) → Future<void>
initSDK() → Future<void>
isInterstitialLoaded(AppLovinListener listener) → Future<bool?>
isRewardLoaded(AppLovinListener listener) → Future<bool?>
setPrivacy(bool hasConsent, bool doNotSell, bool isAgeRestricted) → Future<void>
setUser(String userId) → Future<void>
showInterstitialVideo(AppLovinListener listener) → Future<void>
showRewardVideo(AppLovinListener listener) → Future<void>